==> haskell-logict-0.7.1.0-246.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.1.0
visibility:           public
id:                   logict-0.7.1.0-2FqoCJvkdNzLCCh5fiGBZM
key:                  logict-0.7.1.0-2FqoCJvkdNzLCCh5fiGBZM
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  3242c5c24d935c6ea47e93a6d09abf4e
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.2.8/site-local/logict-0.7.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/logict-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.7.1.0-2FqoCJvkdNzLCCh5fiGBZM
depends:              base-4.16.4.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.7.1.0-250.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.1.0
visibility:           public
id:                   logict-0.7.1.0-4RUNWynDO5NBZa0A2p1eBM
key:                  logict-0.7.1.0-4RUNWynDO5NBZa0A2p1eBM
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  0c658d9b1b726ec5a13e46a443533b98
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.2.8/site-local/logict-0.7.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/logict-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.7.1.0-4RUNWynDO5NBZa0A2p1eBM
depends:              base-4.16.4.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
